slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPVectorsViewFromOptions

Processes command line options to determine if/how the computed eigenvectors are to be viewed.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPVectorsViewFromOptions(NEP nep)

Collective on nep

### Input Parameter

| nep | - the nonlinear eigensolver context

### See Also

NEPVectorsView()

### Level

developer

### Location

src/nep/interface/nepview.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages